const idRegexp = /(?:\.d)?\.(?:ts|js|jsx|tsx)$/;
const ViteUsing = () => ({
  name: "vite-using",
  enforce: "pre",
  transform(code, id) {
    if (idRegexp.test(id)) {
      code = transformUsing(code);
    }
    return code;
  }
});
const usingRegex = /(?<async>await\s+)?using\s+(?<assignment>(?<name>\w+)\s*=\s*(.+)\s*;?)/g;
const transformUsing = (code) => {
  const matched = [...code.matchAll(usingRegex)].reverse();
  matched.forEach((match) => {
    const { index } = match;
    if (!index)
      return;
    const { async, assignment, name } = match.groups;
    const indexOfBlockEnd = findBlockEnd(code, index + match[0].length);
    if (!indexOfBlockEnd)
      return;
    const block = code.slice(index + match[0].length, indexOfBlockEnd);
    const transformed = `
      const ${assignment}
      try {
        ${block}
      } finally {
        ${async ?? ""}${name}[Symbol.${async ? "asyncDispose" : "dispose"}]?.();
      }
    `;
    code = code.slice(0, index) + transformed + code.slice(indexOfBlockEnd);
  });
  return code;
};
const findBlockEnd = (code, start) => {
  let depth = 1;
  let i = start - 1;
  while (i++ < code.length) {
    depth += Number(code[i] === "{") - Number(code[i] === "}");
    if (depth === 0)
      return i;
  }
  return null;
};

export { ViteUsing, ViteUsing as default };
//# sourceMappingURL=index.js.map
